@@ -28,11 +28,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "shape_config.h"
 #include "../util/io/temp_file.h"
 #include "../basic/match.h"
-#include "../data/sorted_list.h"
 #include "../basic/translate.h"
 #include "../dp/dp.h"
 #include "masking.h"
 #include "../util/system/system.h"
+#include "../util/simd.h"
 
 using namespace std;
 
@@ -72,7 +72,9 @@ Config::Config(int argc, const char **argv)
 		.add_command("cluster", "")
 		.add_command("translate", "")
 		.add_command("filter-blasttab", "")
-		.add_command("show-cbs", "");
+		.add_command("show-cbs", "")
+		.add_command("simulate-seqs", "")
+		.add_command("split", "");
 
 	Options_group general("General options");
 	general.add()
@@ -171,7 +173,8 @@ Config::Config(int argc, const char **argv)
 		("taxonmap", 0, "protein accession to taxid mapping file", prot_accession2taxid)
 		("taxonnodes", 0, "taxonomy nodes.dmp from NCBI", nodesdmp)
 		("taxonnames", 0, "taxonomy names.dmp from NCBI", namesdmp)
-		("taxonlist", 0, "restrict search to list of taxon ids (comma-separated)", taxonlist);
+		("taxonlist", 0, "restrict search to list of taxon ids (comma-separated)", taxonlist)
+		("taxon-exclude", 0, "exclude list of taxon ids (comma-separated)", taxon_exclude);
 
 	Options_group advanced("Advanced options");
 	advanced.add()
@@ -197,7 +200,10 @@ Config::Config(int argc, const char **argv)
 		("dbsize", 0, "effective database size (in letters)", db_size)
 		("no-auto-append", 0, "disable auto appending of DAA and DMND file extensions", no_auto_append)
 		("xml-blord-format", 0, "Use gnl|BL_ORD_ID| style format in XML output", xml_blord_format)
-		("stop-match-score", 0, "Set the match score of stop codons against each other.", stop_match_score, 1);
+		("stop-match-score", 0, "Set the match score of stop codons against each other.", stop_match_score, 1)
+		("tantan-minMaskProb", 0, "minimum repeat probability for masking (0.9)", tantan_minMaskProb, 0.9)
+		("tantan-maxRepeatOffset", 0, "maximum tandem repeat period to consider (50)", tantan_maxRepeatOffset, 15)
+		("tantan-ungapped", 0, "use tantan masking in ungapped mode", tantan_ungapped);
 
 	Options_group view_options("View options");
 	view_options.add()
@@ -263,7 +269,6 @@ Config::Config(int argc, const char **argv)
 		("join-split-key-len", 0, "", join_split_key_len, 17u)
 		("radix-bits", 0, "", radix_bits, 8u)
 		("join-ht-factor", 0, "", join_ht_factor, 1.3)
-		("hash-join", 0, "", hash_join)
 		("sort-join", 0, "", sort_join)
 		("simple-freq", 0, "", simple_freq)
 		("freq-treshold", 0, "", freq_treshold)
@@ -274,10 +279,9 @@ Config::Config(int argc, const char **argv)
 		("query-parallel-limit", 0, "", query_parallel_limit, 1000000u)
 		("hard-masked", 0, "", hardmasked)
 		("cbs-window", 0, "", cbs_window, 40)
-		("tantan-r", 0, "", tantan_r, 0.005)
-		("tantan-s", 0, "", tantan_s, 0.5)
 		("no-unlink", 0, "", no_unlink)
-		("no-dict", 0, "", no_dict);
+		("no-dict", 0, "", no_dict)
+		("swipe", 0, "", swipe_all);
 		
 	parser.add(general).add(makedb).add(aligner).add(advanced).add(view_options).add(getseq_options).add(hidden_options);
 	parser.store(argc, argv, command);
@@ -427,7 +431,7 @@ Config::Config(int argc, const char **argv)
 		
 		init_cbs();
 		raw_ungapped_xdrop = score_matrix.rawscore(ungapped_xdrop);
-		simd_messages();
+		verbose_stream << "CPU features detected: " << SIMD::features() << endl;
 	}
 
 	Translator::init(query_gencode);
@@ -449,5 +453,10 @@ Config::Config(int argc, const char **argv)
 	/*log_stream << "sizeof(hit)=" << sizeof(hit) << " sizeof(packed_uint40_t)=" << sizeof(packed_uint40_t)
 		<< " sizeof(sorted_list::entry)=" << sizeof(sorted_list::entry) << endl;*/
 
+	if (swipe_all) {
+		algo = double_indexed;
+		ext = swipe;
+	}
+
 	use_lazy_dict = false;
 }
