@@ -155,7 +155,6 @@ struct Config
 	unsigned join_split_key_len;
 	unsigned radix_bits;
 	double join_ht_factor;
-	bool hash_join;
 	bool sort_join;
 	bool simple_freq;
 	double freq_treshold;
@@ -175,15 +174,19 @@ struct Config
 	bool hardmasked;
 	int cbs_window;
 	double tantan_r;
-	double tantan_s;
+	double tantan_minMaskProb;
 	bool no_unlink;
 	bool no_dict;
 	int stop_match_score;
+	int tantan_maxRepeatOffset;
+	bool tantan_ungapped;
+	string taxon_exclude;
+	bool swipe_all;
 
 	enum {
 		makedb = 0, blastp = 1, blastx = 2, view = 3, help = 4, version = 5, getseq = 6, benchmark = 7, random_seqs = 8, compare = 9, sort = 10, roc = 11, db_stat = 12, model_sim = 13,
 		match_file_stat = 14, model_seqs = 15, opt = 16, mask = 17, fastq2fasta = 18, dbinfo = 19, test_extra = 20, test_io = 21, db_annot_stats = 22, read_sim = 23, info = 24, seed_stat = 25,
-		smith_waterman = 26, protein_snps = 27, cluster = 28, translate = 29, filter_blasttab = 30, show_cbs = 31
+		smith_waterman = 26, protein_snps = 27, cluster = 28, translate = 29, filter_blasttab = 30, show_cbs = 31, simulate_seqs = 32, split = 33
 	};
 	unsigned	command;
 
