@@ -17,8 +17,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #include <math.h>
+#include <algorithm>
 #include "masking.h"
 #include "../lib/tantan/tantan.hh"
+#include "../lib/tantan/LambdaCalculator.hh"
 
 using namespace std;
 
@@ -27,12 +29,21 @@ const uint8_t Masking::bit_mask = 128;
 
 Masking::Masking(const Score_matrix &score_matrix)
 {
-	const double lambda = score_matrix.lambda(); // 0.324032
+	const unsigned n = value_traits.alphabet_size;
+	int int_matrix[20][20], *int_matrix_ptr[20];
+	std::copy(int_matrix, int_matrix + 20, int_matrix_ptr);
+	for (int i = 0; i < 20; ++i)
+		for (int j = 0; j < 20; ++j)
+			int_matrix[i][j] = score_matrix((char)i, (char)j);
+	cbrc::LambdaCalculator lc;
+	lc.calculate(int_matrix_ptr, 20);
+	
+	const double lambda = lc.lambda(); // 0.324032
 	for (unsigned i = 0; i < size; ++i) {
 		mask_table_x_[i] = value_traits.mask_char;
 		mask_table_bit_[i] = (uint8_t)i | bit_mask;
 		for (unsigned j = 0; j < size; ++j)
-			if (i < value_traits.alphabet_size && j < value_traits.alphabet_size)
+			if (i < n && j < n)
 				likelihoodRatioMatrix_[i][j] = exp(lambda * score_matrix(i, j));
 	}
 	std::copy(likelihoodRatioMatrix_, likelihoodRatioMatrix_ + size, probMatrixPointers_);
@@ -44,22 +55,22 @@ Masking::Masking(const Score_matrix &score_matrix)
 
 void Masking::operator()(Letter *seq, size_t len) const
 {
-	tantan::maskSequences((tantan::uchar*)seq, (tantan::uchar*)(seq + len), 50,
+	tantan::maskSequences((tantan::uchar*)seq, (tantan::uchar*)(seq + len), config.tantan_maxRepeatOffset,
 		(tantan::const_double_ptr*)probMatrixPointers_,
-		config.tantan_r, 0.05,
+		0.005, 0.05,
 		0.9,
-		0, 0,
-		config.tantan_s, (const tantan::uchar*)mask_table_x_);
+		config.tantan_ungapped ? 0.0 : firstGapProb_, config.tantan_ungapped ? 0.0 : otherGapProb_,
+		config.tantan_minMaskProb, (const tantan::uchar*)mask_table_x_);
 }
 
 void Masking::mask_bit(Letter *seq, size_t len) const
 {
-	tantan::maskSequences((tantan::uchar*)seq, (tantan::uchar*)(seq + len), 50,
+	tantan::maskSequences((tantan::uchar*)seq, (tantan::uchar*)(seq + len), config.tantan_maxRepeatOffset,
 		(tantan::const_double_ptr*)probMatrixPointers_,
-		config.tantan_r, 0.05,
+		0.005, 0.05,
 		0.9,
-		0, 0,
-		config.tantan_s, (const tantan::uchar*)mask_table_bit_);
+		config.tantan_ungapped ? 0.0 : firstGapProb_, config.tantan_ungapped ? 0.0 : otherGapProb_,
+		config.tantan_minMaskProb, (const tantan::uchar*)mask_table_bit_);
 }
 
 void Masking::bit_to_hard_mask(Letter *seq, size_t len, size_t &n) const
@@ -88,7 +99,7 @@ void mask_worker(Atomic<size_t> *next, Sequence_set *seqs, const Masking *maskin
 			masking->mask_bit(seqs->ptr(i), seqs->length(i));
 }
 
-void mask_seqs(Sequence_set &seqs, const Masking &masking, bool hard_mask)
+size_t mask_seqs(Sequence_set &seqs, const Masking &masking, bool hard_mask)
 {
 	vector<thread> threads;
 	Atomic<size_t> next(0);
@@ -96,4 +107,8 @@ void mask_seqs(Sequence_set &seqs, const Masking &masking, bool hard_mask)
 		threads.emplace_back(mask_worker, &next, &seqs, &masking, hard_mask);
 	for (auto &t : threads)
 		t.join();
+	size_t n = 0;
+	for (size_t i = 0; i < seqs.get_length(); ++i)
+		n += std::count(seqs[i].data(), seqs[i].end(), value_traits.mask_char);
+	return n;
 }
\ No newline at end of file
