@@ -79,13 +79,13 @@ struct Pos_record
 void DatabaseFile::init()
 {
 	read_header(*this, ref_header);
-	*this >> header2;
 	if (ref_header.build < min_build_required || ref_header.db_version < MIN_DB_VERSION)
 		throw std::runtime_error("Database was built with an older version of Diamond and is incompatible.");
 	if (ref_header.db_version > ReferenceHeader::current_db_version)
 		throw std::runtime_error("Database was built with a newer version of Diamond and is incompatible.");
 	if (ref_header.sequences == 0)
 		throw std::runtime_error("Incomplete database file. Database building did not complete successfully.");
+	*this >> header2;
 	pos_array_offset = ref_header.pos_array_offset;
 }
 
@@ -268,7 +268,7 @@ void DatabaseFile::seek_direct() {
 	seek(sizeof(ReferenceHeader) + sizeof(ReferenceHeader2) + 8);
 }
 
-bool DatabaseFile::load_seqs(vector<unsigned> &block_to_database_id, size_t max_letters, bool masked, Sequence_set **dst_seq, String_set<0> **dst_id, bool load_ids, const vector<bool> *filter)
+bool DatabaseFile::load_seqs(vector<unsigned> &block_to_database_id, size_t max_letters, Sequence_set **dst_seq, String_set<0> **dst_id, bool load_ids, const vector<bool> *filter)
 {
 	task_timer timer("Loading reference sequences");
 	seek(pos_array_offset);
@@ -318,7 +318,6 @@ bool DatabaseFile::load_seqs(vector<unsigned> &block_to_database_id, size_t max_
 	(*dst_seq)->finish_reserve();
 	if(load_ids) (*dst_id)->finish_reserve();
 	seek(start_offset);
-	size_t masked_letters = 0;
 
 	for (size_t n = 0; n < seqs; ++n) {
 		if (filter && filtered_pos[n]) seek(filtered_pos[n]);
@@ -329,16 +328,12 @@ bool DatabaseFile::load_seqs(vector<unsigned> &block_to_database_id, size_t max_
 			read((*dst_id)->ptr(n), (*dst_id)->length(n) + 1);
 		else
 			if (!seek_forward('\0')) throw std::runtime_error("Unexpected end of file.");
-		if (config.masking == 1 && masked)
-			Masking::get().bit_to_hard_mask((*dst_seq)->ptr(n), (*dst_seq)->length(n), masked_letters);
-		else
-			Masking::get().remove_bit_mask((*dst_seq)->ptr(n), (*dst_seq)->length(n));
+		Masking::get().remove_bit_mask((*dst_seq)->ptr(n), (*dst_seq)->length(n));
 		if (!config.sfilt.empty() && strstr((**dst_id)[n].c_str(), config.sfilt.c_str()) == 0)
 			memset((*dst_seq)->ptr(n), value_traits.mask_char, (*dst_seq)->length(n));
 	}
 	timer.finish();
 	(*dst_seq)->print_stats();
-	log_stream << "Masked letters = " << masked_letters << endl;
 
 	blocked_processing = seqs_processed < ref_header.sequences;
 	return true;
