@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -26,10 +26,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../util/thread.h"
 #include "../basic/seed_iterator.h"
 #include "seed_set.h"
+#include "../util/data_structures/array.h"
 
 using std::vector;
 
-typedef vector<Array<unsigned,Const::seedp> > shape_histogram;
+typedef vector<Array<unsigned, Const::seedp>> shape_histogram;
 
 struct SeedPartitionRange
 {
@@ -91,10 +92,8 @@ struct Partitioned_histogram
 		data_(shapes.count()),
 		p_(seqs.partition(config.threads_))
 	{
-		for (unsigned s = 0; s < shapes.count(); ++s) {
+		for (unsigned s = 0; s < shapes.count(); ++s)
 			data_[s].resize(p_.size() - 1);
-			memset(data_[s].data(), 0, (p_.size() - 1)*sizeof(unsigned)*Const::seedp);
-		}
 		PtrVector<Callback> cb;
 		for (size_t i = 0; i < p_.size() - 1; ++i)
 			cb.push_back(new Callback(i, data_));
