@@ -1,6 +1,6 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
+Copyright (C) 2013-2019 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,11 +25,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <list>
 #include <stdint.h>
 #include <limits>
+#include <vector>
 #include "../basic/match.h"
 #include "score_profile.h"
 #include "../basic/translated_position.h"
-
-using std::list;
+#include "../util/simd.h"
 
 void init_cbs();
 
@@ -39,7 +39,7 @@ struct No_score_correction
 	{}
 };
 
-struct Bias_correction : public vector<float>
+struct Bias_correction : public std::vector<float>
 {
 	Bias_correction(const sequence &seq);
 	void operator()(float &score, int i, int query_anchor, int mult) const
@@ -48,6 +48,7 @@ struct Bias_correction : public vector<float>
 	}
 	int operator()(const Hsp &hsp) const;
 	int operator()(const Diagonal_segment &d) const;
+	std::vector<int16_t> int16;
 };
 
 struct Seed_hit
@@ -70,10 +71,10 @@ struct Seed_hit
 	{
 		return ungapped.score > rhs.ungapped.score;
 	}
-	bool is_enveloped(list<Hsp>::const_iterator begin, list<Hsp>::const_iterator end, int dna_len) const
+	bool is_enveloped(std::list<Hsp>::const_iterator begin, std::list<Hsp>::const_iterator end, int dna_len) const
 	{
 		const DiagonalSegment d(ungapped, ::Frame(frame_));
-		for (list<Hsp>::const_iterator i = begin; i != end; ++i)
+		for (std::list<Hsp>::const_iterator i = begin; i != end; ++i)
 			if (i->envelopes(d, dna_len))
 				return true;
 		return false;
@@ -505,17 +506,11 @@ struct Diag_scores {
 
 struct DpTarget
 {
-	DpTarget()
-	{}
-	DpTarget(const sequence &seq):
-		seq(seq)
-	{}
-	DpTarget(const sequence &seq, int d_begin, int d_end, list<Hsp> *out = 0, int subject_id=0):
+	DpTarget(const sequence &seq, int d_begin, int d_end, int target_idx = 0) :
 		seq(seq),
 		d_begin(d_begin),
 		d_end(d_end),
-		subject_id(subject_id),
-		out(out)
+		target_idx(target_idx)
 	{}
 	int left_i1() const
 	{
@@ -526,10 +521,7 @@ struct DpTarget
 		return left_i1() < x.left_i1();
 	}
 	sequence seq;
-	int d_begin, d_end, score, subject_id;
-	bool overflow;
-	list<Hsp> *out;
-	Hsp *tmp;
+	int d_begin, d_end, target_idx;
 };
 
 struct DpStat
@@ -557,13 +549,32 @@ void smith_waterman(sequence q, sequence s, Hsp &out);
 void smith_waterman(sequence q, sequence s, const Diag_graph &diags);
 int score_range(sequence query, sequence subject, int i, int j, int j_end);
 
-void swipe(const sequence &query, vector<DpTarget>::const_iterator subject_begin, vector<DpTarget>::const_iterator subject_end, vector<int>::iterator out);
+namespace DP {
+
+struct Traceback {};
+struct ScoreOnly {};
+
+enum { TRACEBACK = 1 };
+	
+namespace Swipe {
+
+DECL_DISPATCH(std::list<Hsp>, swipe, (const sequence &query, const sequence *subject_begin, const sequence *subject_end, int score_cutoff))
+
+}
+
+namespace BandedSwipe {
+
+DECL_DISPATCH(std::list<Hsp>, swipe, (const sequence &query, std::vector<DpTarget>::iterator target_begin, std::vector<DpTarget>::iterator target_end, Frame frame, const Bias_correction &composition_bias, int flags))
+
+}
+
+}
+
 void banded_sw(const sequence &query, const sequence &subject, int d_begin, int d_end, int j_begin, int j_end, Hsp &out);
 
 void anchored_3frame_dp(const TranslatedSequence &query, sequence &subject, const DiagonalSegment &anchor, Hsp &out, int gap_open, int gap_extend, int frame_shift);
 int sw_3frame(const TranslatedSequence &query, Strand strand, const sequence &subject, int gap_open, int gap_extend, int frame_shift, Hsp &out);
 
-void banded_swipe(const sequence &query, vector<DpTarget>::iterator target_begin, vector<DpTarget>::iterator target_end);
-void banded_3frame_swipe(const TranslatedSequence &query, Strand strand, vector<DpTarget>::iterator target_begin, vector<DpTarget>::iterator target_end, DpStat &stat, bool score_only, bool parallel);
+DECL_DISPATCH(std::list<Hsp>, banded_3frame_swipe, (const TranslatedSequence &query, Strand strand, vector<DpTarget>::iterator target_begin, vector<DpTarget>::iterator target_end, DpStat &stat, bool score_only, bool parallel))
 
 #endif /* FLOATING_SW_H_ */
\ No newline at end of file
