@@ -23,7 +23,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../data/queries.h"
 #include "../basic/statistics.h"
 #include "../basic/shape_config.h"
-#include "../search/align_range.h"
 #include "../util/seq_file_format.h"
 #include "../data/load_seqs.h"
 #include "../output/output_format.h"
@@ -43,80 +42,6 @@ using namespace std;
 
 namespace Workflow { namespace Search {
 
-void search_worker(size_t p, size_t thread_id, unsigned sid, const sorted_list *ref_idx, const sorted_list *query_idx) {
-	Statistics stat;
-	align_partition((unsigned)p,
-		stat,
-		sid,
-		ref_idx->get_partition_cbegin(p),
-		query_idx->get_partition_cbegin(p),
-		thread_id);
-	statistics += stat;
-}
-
-
-void process_shape(unsigned sid,
-	unsigned query_chunk,
-	char *query_buffer,
-	char *ref_buffer)
-{
-	using std::vector;
-
-	::partition<unsigned> p(Const::seedp, config.lowmem);
-	for (unsigned chunk = 0; chunk < p.parts; ++chunk) {
-
-		message_stream << "Processing query chunk " << query_chunk << ", reference chunk " << current_ref_block << ", shape " << sid << ", index chunk " << chunk << '.' << endl;
-		const SeedPartitionRange range(p.getMin(chunk), p.getMax(chunk));
-		current_range = range;
-
-		task_timer timer("Building reference index", true);
-		sorted_list *ref_idx;
-		if (config.algo == Config::query_indexed)
-			ref_idx = new sorted_list(ref_buffer,
-				*ref_seqs::data_,
-				sid,
-				ref_hst.get(sid),
-				range,
-				ref_hst.partition(),
-				query_seeds);
-		else if (query_seeds_hashed != 0)
-			ref_idx = new sorted_list(ref_buffer,
-				*ref_seqs::data_,
-				sid,
-				ref_hst.get(sid),
-				range,
-				ref_hst.partition(),
-				query_seeds_hashed);
-		else
-			ref_idx = new sorted_list(ref_buffer,
-				*ref_seqs::data_,
-				sid,
-				ref_hst.get(sid),
-				range,
-				ref_hst.partition(),
-				&no_filter);
-
-		timer.go("Building query index");
-		sorted_list query_idx(query_buffer,
-			*query_seqs::data_,
-			sid,
-			query_hst.get(sid),
-			range,
-			query_hst.partition(),
-			&no_filter);
-
-		if (!config.simple_freq) {
-			timer.go("Building seed filter");
-			frequent_seeds.build(sid, range, *ref_idx, query_idx);
-		}
-		
-		timer.go("Searching alignments");
-		Util::Parallel::scheduled_thread_pool_auto(config.threads_, Const::seedp, search_worker, sid, ref_idx, &query_idx);
-
-		delete ref_idx;
-	}
-}
-
 void run_ref_chunk(DatabaseFile &db_file,
 	Timer &total_timer,
 	unsigned query_chunk,
@@ -129,33 +54,41 @@ void run_ref_chunk(DatabaseFile &db_file,
 	const vector<unsigned> &block_to_database_id)
 {
 	log_stream << "Current RSS: " << getCurrentRSS() << ", Peak RSS: " << getPeakRSS() << endl;
-	task_timer timer("Building reference histograms");
-	if(config.algo==Config::query_indexed)
-		ref_hst = Partitioned_histogram(*ref_seqs::data_, false, query_seeds);
-	else if(query_seeds_hashed != 0)
-		ref_hst = Partitioned_histogram(*ref_seqs::data_, true, query_seeds_hashed);
-	else
-		ref_hst = Partitioned_histogram(*ref_seqs::data_, false, &no_filter);
+
+	task_timer timer;
+	if (config.masking == 1) {
+		timer.go("Masking reference");
+		size_t n = mask_seqs(*ref_seqs::data_, Masking::get());
+		timer.finish();
+		log_stream << "Masked letters: " << n << endl;
+	}
 
 	ReferenceDictionary::get().init(safe_cast<unsigned>(ref_seqs::get().get_length()), block_to_database_id);
 
-	timer.go("Allocating buffers");
-	char *ref_buffer = sorted_list::alloc_buffer(ref_hst);
-
 	timer.go("Initializing temporary storage");
 	Trace_pt_buffer::instance = new Trace_pt_buffer(query_seqs::data_->get_length() / align_mode.query_contexts,
 		config.tmpdir,
 		config.query_bins);
-	timer.finish();
-	
-	for (unsigned i = 0; i < shapes.count(); ++i)
-		if (config.hash_join)
-			search_shape(i, query_chunk);
-		else
-			process_shape(i, query_chunk, query_buffer, ref_buffer);
 
-	timer.go("Deallocating buffers");
-	delete[] ref_buffer;
+	if (!config.swipe_all) {
+		timer.go("Building reference histograms");
+		if (config.algo == Config::query_indexed)
+			ref_hst = Partitioned_histogram(*ref_seqs::data_, false, query_seeds);
+		else if (query_seeds_hashed != 0)
+			ref_hst = Partitioned_histogram(*ref_seqs::data_, true, query_seeds_hashed);
+		else
+			ref_hst = Partitioned_histogram(*ref_seqs::data_, false, &no_filter);
+
+		timer.go("Allocating buffers");
+		char *ref_buffer = SeedArray::alloc_buffer(ref_hst);	
+		timer.finish();
+
+		for (unsigned i = 0; i < shapes.count(); ++i)
+			search_shape(i, query_chunk, query_buffer, ref_buffer);
+
+		timer.go("Deallocating buffers");
+		delete[] ref_buffer;
+	}
 
 	Consumer* out;
 	if (blocked_processing) {
@@ -218,26 +151,29 @@ void run_query_chunk(DatabaseFile &db_file,
 		timer.go("Building query seed hash set");
 		query_seeds_hashed = new Hashed_seed_set(query_seqs::get());
 	}
+	timer.finish();
 
-	timer.go("Building query histograms");
+	char *query_buffer = nullptr;
 	const pair<size_t, size_t> query_len_bounds = query_seqs::data_->len_bounds(shapes[0].length_);
 	setup_search_params(query_len_bounds, 0);
-	query_hst = Partitioned_histogram(*query_seqs::data_, false, &no_filter);
-	timer.finish();
-	//const bool long_addressing_query = query_seqs::data_->raw_len() > (size_t)std::numeric_limits<uint32_t>::max();
 
-	timer.go("Allocating buffers");
-	char *query_buffer = sorted_list::alloc_buffer(query_hst);
+	if (!config.swipe_all) {
+		timer.go("Building query histograms");		
+		query_hst = Partitioned_histogram(*query_seqs::data_, false, &no_filter);
+		
+		timer.go("Allocating buffers");
+		query_buffer = SeedArray::alloc_buffer(query_hst);
+		timer.finish();
+	}
+	
 	PtrVector<TempFile> tmp_file;
 	query_aligned.clear();
 	query_aligned.insert(query_aligned.end(), query_ids::get().get_length(), false);
 	db_file.rewind();
 	vector<unsigned> block_to_database_id;
-	timer.finish();
-	
+
 	for (current_ref_block = 0; db_file.load_seqs(block_to_database_id,
 		(size_t)(config.chunk_size*1e9),
-		true,
 		&ref_seqs::data_,
 		&ref_ids::data_,
 		true,
@@ -308,7 +244,6 @@ void master_thread(DatabaseFile *db_file, Timer &total_timer, Metadata &metadata
 			db_file->seek_seq(query_file_offset);
 			if (!db_file->load_seqs(query_block_to_database_id,
 				(size_t)(config.chunk_size * 1e9),
-				true,
 				&query_seqs::data_,
 				&query_ids::data_,
 				true,
@@ -404,21 +339,22 @@ void run(const Options &options)
 	set_max_open_files(config.query_bins * config.threads_ + unsigned(db_file->ref_header.letters / (size_t)(config.chunk_size * 1e9)) + 16);
 
 	Metadata metadata;
-	if (output_format->needs_taxon_id_lists || !config.taxonlist.empty()) {
-		if (!config.taxonlist.empty() && db_file->header2.taxon_array_offset == 0)
-			throw std::runtime_error("--taxonlist option requires taxonomy mapping built into the database.");
+	const bool taxon_filter = !config.taxonlist.empty() || !config.taxon_exclude.empty();
+	if (output_format->needs_taxon_id_lists || taxon_filter) {
+		if (taxon_filter && db_file->header2.taxon_array_offset == 0)
+			throw std::runtime_error("--taxonlist/--taxon-exclude options require taxonomy mapping built into the database.");
 		timer.go("Loading taxonomy mapping");
 		metadata.taxon_list = new TaxonList(db_file->seek(db_file->header2.taxon_array_offset), db_file->ref_header.sequences, db_file->header2.taxon_array_size);
 		timer.finish();
 	}
-	if (output_format->needs_taxon_nodes || !config.taxonlist.empty()) {
-		if (!config.taxonlist.empty() && db_file->header2.taxon_nodes_offset == 0)
-			throw std::runtime_error("--taxonlist option requires taxonomy nodes built into the database.");
+	if (output_format->needs_taxon_nodes || taxon_filter) {
+		if (taxon_filter && db_file->header2.taxon_nodes_offset == 0)
+			throw std::runtime_error("--taxonlist/--taxon-exclude options require taxonomy nodes built into the database.");
 		timer.go("Loading taxonomy nodes");
 		metadata.taxon_nodes = new TaxonomyNodes(db_file->seek(db_file->header2.taxon_nodes_offset));
-		if (!config.taxonlist.empty()) {
+		if (taxon_filter) {
 			timer.go("Building taxonomy filter");
-			metadata.taxon_filter = new TaxonomyFilter(config.taxonlist, *metadata.taxon_list, *metadata.taxon_nodes);
+			metadata.taxon_filter = new TaxonomyFilter(config.taxonlist, config.taxon_exclude, *metadata.taxon_list, *metadata.taxon_nodes);
 		}
 		timer.finish();
 	}
