@@ -46,7 +46,7 @@ void random_seqs()
 {
 	DatabaseFile db_file(config.database);
 	vector<unsigned> v;
-	db_file.load_seqs(v, std::numeric_limits<size_t>::max(), true, &ref_seqs::data_, &ref_ids::data_);
+	db_file.load_seqs(v, std::numeric_limits<size_t>::max(), &ref_seqs::data_, &ref_ids::data_);
 	cout << "Sequences = " << ref_seqs::get().get_length() << endl;
 	std::set<unsigned> n;
 	const size_t count = atoi(config.seq_no[0].c_str());
@@ -89,7 +89,7 @@ void db_stat()
 {
 	DatabaseFile db_file(config.database);
 	vector<unsigned> v;
-	db_file.load_seqs(v, std::numeric_limits<size_t>::max(), true, &ref_seqs::data_, &ref_ids::data_);
+	db_file.load_seqs(v, std::numeric_limits<size_t>::max(), &ref_seqs::data_, &ref_ids::data_);
 	cout << "Sequences = " << ref_seqs::get().get_length() << endl;
 
 	size_t letters = 0;
@@ -116,6 +116,7 @@ void run_masker()
 	vector<Letter> seq, seq2;
 	vector<char> id;
 	const FASTA_format format;
+	size_t letters = 0, seqs = 0, seqs_total = 0;
 	while (format.get_seq(id, seq, f)) {
 		cout << '>' << string(id.data(), id.size()) << endl;
 		seq2 = seq;
@@ -128,6 +129,16 @@ void run_masker()
 		}
 		cout << endl;*/
 		cout << sequence(seq2.data(), seq2.size()) << endl;
+		size_t n = 0;
+		for (size_t i = 0; i < seq2.size(); ++i)
+			if (seq2[i] == value_traits.mask_char) {
+				++n;
+			}
+		letters += n;
+		if (n > 0)
+			++seqs;
+		++seqs_total;
+		cerr << "#Sequences: " << seqs << "/" << seqs_total << ", #Letters: " << letters << endl;
 	}
 }
 
@@ -159,7 +170,7 @@ void test_io()
 
 	DatabaseFile db(config.database);
 	vector<unsigned> v;
-	db.load_seqs(v, std::numeric_limits<size_t>::max(), true, &ref_seqs::data_, &ref_ids::data_);
+	db.load_seqs(v, std::numeric_limits<size_t>::max(), &ref_seqs::data_, &ref_ids::data_);
 
 	size_t total = ref_seqs::get().raw_len() + ref_ids::get().raw_len();
 	cout << "MBytes/sec = " << total / 1e6 / t.getElapsedTime() << endl;
