@@ -208,34 +208,6 @@ inline int abs_diff(unsigned x, unsigned y)
 	return abs((int)x - int(y));
 }
 
-template<typename _t, size_t n>
-struct Array
-{
-	Array()
-	{}
-	_t& operator[](size_t i)
-	{
-		return data_[i];
-	}
-	const _t& operator[](size_t i) const
-	{
-		return data_[i];
-	}
-	_t* begin()
-	{
-		return data_;
-	}
-	const _t* begin() const
-	{
-		return data_;
-	}
-	_t* end()
-	{
-		return data_ + n;
-	}
-	_t data_[n];
-};
-
 template<typename _t, int _n>
 struct Static_vector
 {
@@ -518,11 +490,11 @@ inline string hex_print(const char *x, int len) {
 	return out;
 }
 
-inline set<unsigned> parse_csv(const string &s)
+inline std::set<unsigned> parse_csv(const std::string &s)
 {
-	set<unsigned> r;
-	vector<string> t(tokenize(s.c_str(), ","));
-	for (vector<string>::const_iterator i = t.begin(); i != t.end(); ++i)
+	std::set<unsigned> r;
+	std::vector<std::string> t(tokenize(s.c_str(), ","));
+	for (std::vector<std::string>::const_iterator i = t.begin(); i != t.end(); ++i)
 		if(!i->empty()) r.insert(atoi(i->c_str()));
 	return r;
 }
